/*
 * Include file for the Small language definitions of the native functions
 * implemented in the ProMotion "PluginMaker" plug-in.
 *
 * This file is implicitly included in every Small script that is compiled
 * with PluginMaker.
 *
 * (c) Copyright 1999-2001, ITB CompuPhase
 * This file is provided as is. It may be used, modified and distributed,
 * provided that the you acknowledge that there are no warranties (of any
 * kind) provided with this file.
 */
#if defined _plugmake_included
  #endinput
#endif
#define _plugmake_included

/* Core functions (from CORE.INC in the Small archive) */
native heapspace();

native funcidx(const name[]);

native numargs();
native getarg(arg, index=0);
native setarg(arg, index=0, value);

native strlen(const string[]);
native strpack(dest[], const source[]);
native strunpack(dest[], const source[]);

native tolower(c);
native toupper(c);
native swapchars(c);

native random(max);

native min(value1, value2);
native max(value1, value2);
native clamp(value, min=cellmin, max=cellmax);

native getproperty(id=0, const name[]="", value=cellmin, string[]="");
native setproperty(id=0, const name[]="", value=cellmin, const string[]="");
native deleteproperty(id=0, const name[]="", value=cellmin);
native existproperty(id=0, const name[]="", value=cellmin);


/* Functions for fixed-point values (from FIXED.INC in the Small archive) */
enum fround_method {
  fround_round,
  fround_floor,
  fround_ceil
}

native fixed:fixed(value);
native fixed:fixedstr(const string[]);
native fixed:fmul(fixed:oper1, fixed:oper2);
native fixed:fdiv(fixed:dividend, fixed:divisor);
native fixed:ffract(fixed:value);
native       fround(fixed:value, fround_method:method=fround_round);

#pragma rational fixed(3)

native fixed:operator*(fixed:oper1, fixed:oper2) = fmul;
native fixed:operator/(fixed:oper1, fixed:oper2) = fdiv;

stock fixed:operator++(fixed:oper)
    return oper+fixed(1);

stock fixed:operator--(fixed:oper)
    return oper-fixed(1);

stock fixed:operator*(fixed:oper1, oper2)
    return _:oper1 * oper2;                     /* "*" is commutative */

stock fixed:operator/(fixed:oper1, oper2)
    return _:oper1 / oper2;

stock fixed:operator/(oper1, fixed:oper2)
    return fdiv(fixed(oper1), oper2);

stock fixed:operator+(fixed:oper1, oper2)
    return oper1 + fixed(oper2);                /* "+" is commutative */

stock fixed:operator-(fixed:oper1, oper2)
    return oper1 - fixed(oper2);

stock fixed:operator-(oper1, fixed:oper2)
    return fixed(oper1) - oper2;

forward operator%(fixed:oper1, fixed:oper2);    /* forbidden operations */
forward operator%(fixed:oper1, oper2);
forward operator%(oper1, fixed:oper2);


/* Functions specific to Pro Motion */
enum panelsource {
  source,
  preview,
}

native getpixel(x, y, panelsource:panel=source);
native setpixel(x, y, color);
native imagesize(&width=0, &height=0);
native getcontrol(index);
native setcontrol(index, caption[]="", min=cellmin, max=cellmin, pos=cellmin);
native getbgcolor();
native getfgcolor();
native clearimage(color=0);
native copysource();
native setcursor(index);
native handleevents();

